<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="el">
<context>
    <name>QObject</name>
    <message>
        <location filename="../about.cpp" line="41"/>
        <source>License</source>
        <translation>Άδεια</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="42"/>
        <location filename="../about.cpp" line="52"/>
        <source>Changelog</source>
        <translation>Αρχείο αλλαγών</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="43"/>
        <source>Cancel</source>
        <translation>Άκυρο</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="64"/>
        <source>&amp;Close</source>
        <translation>&amp;Κλείσιμο</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="47"/>
        <source>GUI for applying assorted useful tweaks</source>
        <translation>Γραφικό περιβάλλον για την εφαρμογή χρήσιμων βελτιώσεων</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="50"/>
        <source>launches brightness-systray</source>
        <translation>εμφάνιση εικονιδίου στο σύστημα</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="51"/>
        <source>opens with display tab open.  Only valid with Xfce desktop running</source>
        <translation>ανοίγει την εμφάνιση.  Μόνο σε Xfce</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="52"/>
        <source>Opens theme tab directly.  Valid on Xfce &amp; Fluxbox desktops</source>
        <translation>Ανοίγει άμεσα το θέμα. Σε Xfce και Fluxbox</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="53"/>
        <source>Display additional debug output in console</source>
        <translation>Εμφάνιση εντοπισμού σφαλμάτων στην κονσόλα</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="54"/>
        <source>Opens Other tab directly.  Valid on all desktops</source>
        <translation>Ανοίγει τη καρτέλα Άλλα.  Σε όλα τα γραφικά περιβάλλοντα</translation>
    </message>
</context>
<context>
    <name>brightness_small</name>
    <message>
        <location filename="../brightness_small.ui" line="14"/>
        <source>MainWindow</source>
        <translation>Κυρίως παράθυρο</translation>
    </message>
    <message>
        <location filename="../brightness_small.ui" line="39"/>
        <source>Save</source>
        <translation>Αποθήκευση</translation>
    </message>
    <message>
        <location filename="../brightness_small.ui" line="59"/>
        <source>Software (xrandr) Brightness</source>
        <translation>Φωτεινότητα (xrandr)</translation>
    </message>
    <message>
        <location filename="../brightness_small.ui" line="66"/>
        <location filename="../brightness_small.ui" line="87"/>
        <source>TextLabel</source>
        <translation>Επικεφαλίδα</translation>
    </message>
    <message>
        <location filename="../brightness_small.ui" line="80"/>
        <source>Hardware Backlight</source>
        <translation>Οπίσθιος φωτισμός</translation>
    </message>
    <message>
        <location filename="../brightness_small.ui" line="94"/>
        <source>&gt;&gt;</source>
        <translation>&gt;&gt;</translation>
    </message>
    <message>
        <location filename="../brightness_small.cpp" line="33"/>
        <source>MX-Tweak</source>
        <translation>MX Ρυθμίσεις</translation>
    </message>
    <message>
        <location filename="../brightness_small.cpp" line="58"/>
        <source>Display</source>
        <translation>Οθόνη</translation>
    </message>
    <message>
        <location filename="../brightness_small.cpp" line="63"/>
        <source>&amp;Quit</source>
        <translation>&amp;Έξοδος</translation>
    </message>
</context>
<context>
    <name>defaultlook</name>
    <message>
        <location filename="../defaultlook.ui" line="20"/>
        <location filename="../defaultlook.cpp" line="60"/>
        <location filename="../defaultlook.cpp" line="108"/>
        <location filename="../defaultlook.cpp" line="672"/>
        <location filename="../defaultlook.cpp" line="691"/>
        <location filename="../defaultlook.cpp" line="700"/>
        <location filename="../defaultlook.cpp" line="747"/>
        <location filename="../defaultlook.cpp" line="755"/>
        <location filename="../defaultlook.cpp" line="782"/>
        <location filename="../defaultlook.cpp" line="785"/>
        <source>MX Tweak</source>
        <translation>MX Ρυθμίσεις</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="41"/>
        <source>Xfce Settings</source>
        <translation>Ρυθμίσεις Xfce</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="107"/>
        <source>About</source>
        <translation>Περί</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="118"/>
        <source>Help</source>
        <translation>Βοήθεια</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="135"/>
        <source>Quit application</source>
        <translation>Κλείσιμο εφαρμογής</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="138"/>
        <source>Close</source>
        <translation>Κλείσιμο</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="145"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="165"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Customize the panel&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Προτιμήσεις ταμπλό&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="175"/>
        <location filename="../defaultlook.ui" line="259"/>
        <source>Panel</source>
        <translation>Ταμπλό</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="195"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Configure window behavior and shortcuts&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Ρύθμιση παραθύρων και συντομεύσεων&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="209"/>
        <source>Window Manager</source>
        <translation>Διαχειριστής παραθύρων</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="229"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Customize the look of your desktop&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Προσαρμογή εμφάνισης της επιφάνειας εργασίας&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="243"/>
        <source>Appearance</source>
        <translation>Εμφάνιση</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="270"/>
        <source>Display panel horizontally</source>
        <extracomment>panel will be shown in a horizontal configuration</extracomment>
        <translation>Οριζόντια απεικόνιση του ταμπλό</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="280"/>
        <source>Volume</source>
        <extracomment>volume plugin scale factor</extracomment>
        <translation>Μέγεθος</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="287"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Docklike&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <extracomment>affects the docklike plugin</extracomment>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Docklike&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="294"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Affects all panels&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Επηρεάζει όλα τα ταμπλό&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="314"/>
        <location filename="../defaultlook.ui" line="1798"/>
        <source>Bottom</source>
        <translation>Κάτω</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="319"/>
        <location filename="../defaultlook.ui" line="1808"/>
        <source>Top</source>
        <translation>Επάνω</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="327"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:700;&quot;&gt;Tasklist&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:700;&quot;&gt;Λίστα εργασιών&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="334"/>
        <source>Display panel vertically</source>
        <extracomment>panel will be shown in a vertical configuration</extracomment>
        <translation>Κάθετη απεικόνιση του ταμπλό</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="349"/>
        <location filename="../defaultlook.ui" line="1787"/>
        <source>Affects 1st panel</source>
        <extracomment>acts on the first poanel found in Xfce panel xml fle</extracomment>
        <translation>Επηρεάζει το 1ο ταμπλό</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="356"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:700;&quot;&gt;Panel Plugin Scales&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:700;&quot;&gt;Κλίμακες προσθέτων στο ταμπλό&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="376"/>
        <source>Backup current panel configuration</source>
        <extracomment>backup existing panel configuration</extracomment>
        <translation>Αποθήκευση της τρέχουσας διαμόρφωσης του ταμπλό</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="386"/>
        <location filename="../defaultlook.ui" line="446"/>
        <source>Options</source>
        <translation>Επιλογές</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="406"/>
        <source>Power Manager</source>
        <extracomment>power manager plugin scale factor</extracomment>
        <translation>Του πρόσθετου διαχειριστή ρεύματος</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="413"/>
        <source>Restore backup panel configuration</source>
        <extracomment>restore a panel backup</extracomment>
        <translation>Επαναφορά της αποθηκευμένης διαμόρφωσης του ταμπλό</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="436"/>
        <source>Set Scales</source>
        <extracomment>set a scale factor</extracomment>
        <translation>Κλίμακα</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="466"/>
        <location filename="../defaultlook.ui" line="1803"/>
        <source>Left</source>
        <translation>Αριστερά</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="471"/>
        <location filename="../defaultlook.ui" line="1813"/>
        <source>Right</source>
        <translation>Δεξιά</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="479"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Window Buttons&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <extracomment>affects the window button plugin</extracomment>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Κουμπιά παραθύρων&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="500"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Docklike is the modern dock plugin for the panel.  Window Buttons is the classic tasklist without dock features.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Το πρόσθετο Docklike είναι ένα σύγχρονο dock για το ταμπλό.  Τα κουμπιά των παραθύρων είναι η κλασική λίστα εργασιών χωρίς άλλες δυνατότητες.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="523"/>
        <location filename="../defaultlook.ui" line="722"/>
        <location filename="../defaultlook.ui" line="896"/>
        <location filename="../defaultlook.ui" line="1064"/>
        <location filename="../defaultlook.ui" line="1071"/>
        <location filename="../defaultlook.ui" line="1078"/>
        <location filename="../defaultlook.ui" line="1145"/>
        <location filename="../defaultlook.ui" line="1290"/>
        <location filename="../defaultlook.ui" line="1839"/>
        <location filename="../defaultlook.ui" line="1898"/>
        <location filename="../defaultlook.ui" line="2045"/>
        <source>Apply</source>
        <extracomment>apply changes</extracomment>
        <translation>Εφαρμογή</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="543"/>
        <source>Restore default panel</source>
        <extracomment>affects any panel that is curently configured</extracomment>
        <translation>Επαναφορά προεπιλεγμένου ταμπλό</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="553"/>
        <source>Set Tasklist plugin to:</source>
        <extracomment>change the tasklist plugin</extracomment>
        <translation>Καθορισμός πρόσθετου λίστας εργασιών σε:</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="567"/>
        <source>Theme</source>
        <translation>Θέμα</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="575"/>
        <source>Preview</source>
        <translation>Προεπισκόπηση</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="582"/>
        <source>Remove User Theme Set</source>
        <translation>Αφαίρεση θέματος</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="593"/>
        <source>Save Current Settings as a Theme Set</source>
        <extracomment>save theme settings as a group</extracomment>
        <translation>Αποθήκευση των ρυθμίσεων σαν θέμα</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="604"/>
        <source>default</source>
        <extracomment>default pointer size determined by X server</extracomment>
        <translation>προεπιλογή</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="617"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-size:12pt; font-weight:600;&quot;&gt;Themes&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-size:12pt; font-weight:600;&quot;&gt;Θέματα&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="624"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Icons&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <extracomment>icon theme</extracomment>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Εικονίδια&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="631"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Cursors&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <extracomment>cursor theme</extracomment>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Δείκτες ποντικιού&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="638"/>
        <source>Size</source>
        <extracomment>size of the mouse pointer or cursor</extracomment>
        <translation>Μέγεθος</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="651"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Window Manager&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <extracomment>theme a window manager border will get</extracomment>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Διαχειριστής παραθύρων&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="666"/>
        <source>Theme Options</source>
        <translation>Επιλογές</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="682"/>
        <source>Undo</source>
        <translation>Αναίρεση</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="689"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Application&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <extracomment>theme an application will get</extracomment>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Εφαρμογή&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="745"/>
        <location filename="../defaultlook.ui" line="756"/>
        <source>Compositor</source>
        <translation>Συνθέτης</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="763"/>
        <source>Transparency and shadow options</source>
        <translation>Επιλογές διαφάνειας και σκιάς</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="783"/>
        <source>None</source>
        <translation>Κανένας</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="788"/>
        <source>Xfwm (Xfce) Compositor</source>
        <translation>Xfwm (Xfce)</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="793"/>
        <source>Compton </source>
        <translation>Compton </translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="802"/>
        <source>auto</source>
        <translation>auto</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="807"/>
        <source>glx</source>
        <translation>glx</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="812"/>
        <source>xpresent</source>
        <translation>xpresent</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="817"/>
        <location filename="../defaultlook.ui" line="1403"/>
        <source>off</source>
        <extracomment>setting to 0 turns off screensaver screen blank</extracomment>
        <translation>off</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="838"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Changing the VBlank mode may help alleviate some screen tearing issues.  See Help for more information.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt; Η αλλαγή στη λειτουργία VBlank μπορεί να βοηθήσει στην επίλυση ορισμένων ζητημάτων απεικόνισης. Δείτε τη βοήθεια για περισσότερες πληροφορίες.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="841"/>
        <source>VBlank</source>
        <translation>VBlank</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="848"/>
        <source>Launch compton-conf configuration tool</source>
        <translation>Άνοιγμα του εργαλείου Compton-conf</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="851"/>
        <source>Compton settings</source>
        <translation>Ρυθμίσεις Compton</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="862"/>
        <source>Edit compton.conf directly in text editor</source>
        <translation>Επεξεργασία του compton.conf με τον επεξεργαστή κειμένου</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="865"/>
        <source>Edit compton.conf</source>
        <translation>Επεξεργασία του compton.conf</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="876"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Xfce Compositor Settings&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Ρυθμίσεις συνθέτη Xfce&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="879"/>
        <source>Xfwm Settings</source>
        <translation>Ρυθμίσεις Xfwm</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="919"/>
        <source>Display</source>
        <translation>Οθόνη</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="930"/>
        <source>Hardware Backlight</source>
        <extracomment>set the hardware backlight on monitors that have them</extracomment>
        <translation>Οπίσθιος φωτισμός</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="937"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Display Tweaks&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Ρυθμίσεις οθόνης&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="964"/>
        <source>Choose Display for xrandr tweaks</source>
        <extracomment>choose the display that the xrandr tweaks will be acted upon</extracomment>
        <translation>Επιλογή οθόνης για τροποποιήσεις xrandr</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="974"/>
        <source>Resolution</source>
        <translation>Ανάλυση</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="981"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Saving is per display&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Αποθήκευση ανά οθόνη&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="984"/>
        <source>Save</source>
        <translation>Αποθήκευση</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="991"/>
        <source>Software (xrandr) Brightness</source>
        <extracomment>adjust brightness (not backlight) via software</extracomment>
        <translation>Φωτεινότητα (xrandr)</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="998"/>
        <location filename="../defaultlook.ui" line="1095"/>
        <source>TextLabel</source>
        <translation>Επικεφαλίδα</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1005"/>
        <source>GTK scaling</source>
        <extracomment>gtk scale factor</extracomment>
        <translation>Κλίμακα GTK</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1025"/>
        <source>xrandr Scaling</source>
        <extracomment>xrandr scale factor</extracomment>
        <translation>Κλίμακα xrandr</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1121"/>
        <source>Config Options</source>
        <translation>Επιλογές ρυθμίσεων</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1132"/>
        <source>Disable shortening of long filenames on the desktop</source>
        <translation>Απενεργοποίηση σύμπτυξης μεγάλων ονομάτων αρχείων στην επιφάνεια εργασίας</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1156"/>
        <source>                   note: to hibernate, swap needs to be &gt;= RAM</source>
        <translation>                   σημείωση: για την αδρανοποίηση πρέπει το swap να είναι &gt;= RAM</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1176"/>
        <source>Enable single-click on desktop</source>
        <translation>Ενεργοποίηση του μονό κλικ στην επιφάνεια εργασίας</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1183"/>
        <source>Enable hibernate on Log Out menu </source>
        <translation>Ενεργοποίηση της αδρανοποίησης στο μενού αποσύνδεσης </translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1190"/>
        <location filename="../defaultlook.ui" line="1324"/>
        <source>Reset Thunar custom right-click actions to system defaults</source>
        <translation>Επαναφορά των προσαρμοσμένων ενεργειών του δεξιού κλικ στο Thunar στις προεπιλογές του συστήματος</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1197"/>
        <location filename="../defaultlook.ui" line="1375"/>
        <source>Enable single-click in Thunar File Manager</source>
        <translation>Ενεργοποίηση του μονό κλικ στο διαχειριστή αρχείων Thunar</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1204"/>
        <location filename="../defaultlook.ui" line="1636"/>
        <source>Thunar windows always open in split view</source>
        <translation>Τα παράθυρα του Thunar ανοίγουν πάντα σε διαχωρισμένη προβολή</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1211"/>
        <location filename="../defaultlook.ui" line="1568"/>
        <source>Thunar split view opens horizontal</source>
        <translation>Οριζόντιο άνοιγμα διαχωρισμένης προβολής στο Thunar</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1218"/>
        <source>Show percentages in notifcations when available</source>
        <translation>Εμφάνιση ποσοστών στις ειδοποιήσεις όταν αυτό είναι διαθέσιμο</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1225"/>
        <source>Enable Desktop Zoom </source>
        <translation>Ενεργοποίηση μεγένθυνσης της επιφάνειας εργασίας </translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1232"/>
        <location filename="../defaultlook.ui" line="1754"/>
        <source>Show windows from all workspaces in panel</source>
        <translation>Εμφάνιση των παραθύρων από όλους τους χώρους εργασίας στο ταμπλό</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1239"/>
        <source>Show GTK File Dialog action buttons at bottom of dialogs</source>
        <translation>Στα παράθυρα GTK εμφάνιση των κουμπιών στο κάτω μέρος</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1246"/>
        <source>( also turns off Client Side Decorations for Xfce applications)</source>
        <translation>(και κλείσιμο του Client Side Decorations στις εφαρμογές του Xfce)</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1259"/>
        <source>Fluxbox</source>
        <translation>Fluxbox</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1271"/>
        <location filename="../defaultlook.ui" line="1611"/>
        <source>On</source>
        <translation>Ενεργοποίηση</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1276"/>
        <location filename="../defaultlook.ui" line="1616"/>
        <source>Off</source>
        <translation>Απενεργοποίηση</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1297"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Thunar&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Thunar&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1304"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Toolbar Settings&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Ρυθμίσεις γραμμής εργαλείων&lt;/span&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1344"/>
        <source>Toggle icon captions</source>
        <translation>Εναλλαγή λεζάντας εικονιδίων</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1351"/>
        <source>Reset Fluxbox Menu</source>
        <translation>Επαναφορά μενού του Fluxbox</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1368"/>
        <source>Width</source>
        <translation>Πλάτος</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1382"/>
        <source>Toggle desktop icons</source>
        <translation>Εναλλαγή εικονιδίων στην επιφάνεια εργασίας</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1389"/>
        <location filename="../defaultlook.ui" line="1413"/>
        <source>Autohide</source>
        <translation>Αυτόματη απόκρυψη</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1396"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Dock Settings&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Ρυθμίσεις dock&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1487"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Desktop Icons&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Εικονίδια επιφάνειας εργασίας&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1561"/>
        <source>Reset DefaultDock</source>
        <translation>Επαναφορά DefaultDock</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1575"/>
        <source>Manage Tint2 Panel</source>
        <translation>Διαχείρηση ταμπλό Tint2</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1586"/>
        <source>Height</source>
        <translation>Ύψος</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1593"/>
        <location filename="../defaultlook.ui" line="1629"/>
        <location filename="../defaultlook.ui" line="1761"/>
        <source>Placement</source>
        <translation>Τοποθέτηση</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1600"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:700;&quot;&gt;Screensaver&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <extracomment>screensaver screen blank settings</extracomment>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:700;&quot;&gt;Προφύλαξη οθόνης&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1621"/>
        <source>On Hover</source>
        <translation>Σε πέρασμα του δείκτη</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1643"/>
        <location filename="../defaultlook.ui" line="1721"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Reset Defaults&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Επαναφορά προεπιλογών&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1650"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Add new default menu items, if any, to existing fluxbox menu.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Προσθήκη νέων καταχωρήσεων στο μενού του fluxbox, αν υπάρχουν.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1653"/>
        <source>Upgrade existing menu entries</source>
        <translation>Αναβάθμιση καταχωρήσεων μενού</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1673"/>
        <source>Show Toolbar</source>
        <translation>Εμφάνιση εργαλειοθήκης</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1690"/>
        <source>Reset ALL mx-fluxbox settings</source>
        <translation>Επαναφορά ΟΛΩΝ των ρυθμίσεων του mx-fluxbox</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1697"/>
        <source>Idle time (minutes)</source>
        <extracomment>set the time of inactivity  before screensaver screen blank occurs</extracomment>
        <translation>Χρόνος αδράνειας (λεπτά)</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1710"/>
        <source>Plasma</source>
        <translation>Plasma</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1768"/>
        <source>Enable single-click</source>
        <translation>Ενεργοποίηση του απλό κλικ</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1775"/>
        <source>Reset KDE/Plasma defaults</source>
        <translation>Επαναφορά προεπιλογών KDE/Plasma</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1826"/>
        <source>Workspace</source>
        <translation>Χώρος εργασίας</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1850"/>
        <source>Autostart plasma-discover system tray update notification utility</source>
        <extracomment>enable or disable autostartup of plasma-discover updater utility on login</extracomment>
        <translation>Αυτόματη εκκίνηση του βοηθητικού προγράμματος του δοχείου συστήματος plasma-discover για ειδοποιήσεις και ενημερώσεις</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1860"/>
        <source>Super Key</source>
        <extracomment>referring to the meta or Left Super Key</extracomment>
        <translation>Super Key</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1868"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Choose application&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <extracomment>description of button action to launch file dialog to choose an application</extracomment>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Επιλογή εφαρμογής&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1881"/>
        <source>Xfce-superkey defaults</source>
        <extracomment>indicates that xfce-superkey will select a command by its default logic</extracomment>
        <translation>Προεπιλεγμένη εντολή του Xfce για το superkey</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1888"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Also known as the &amp;quot;windows&amp;quot; key&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Γνωστό και ως κουμπί των &amp;quot;windows&amp;quot;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1891"/>
        <source>Command to run with Super (Meta) key</source>
        <extracomment>label for the field to enter the command to use with super key</extracomment>
        <translation>Εντολή που θέλετε να εκτελεί το κουμπί Super (Meta)</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1921"/>
        <source>Other</source>
        <translation>Άλλα</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1929"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;requires reboot&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;απαιτείται επανεκκίνηση&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1932"/>
        <source>Enable Bluetooth adapters on boot</source>
        <translation>Ενεργοποίηση οδηγών Bluetooth στην εκκίνηση</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1939"/>
        <source>Use intel driver instead of default &quot;modesetting&quot; driver (requires restart)</source>
        <translation>Χρήση του προγράμματος οδήγησης intel αντί του προεπιλεγμένου &quot;modesetting&quot; (απαιτείται επανεκκίνηση)</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1946"/>
        <source>          NOTE: existing /etc/X11/xorg.conf.d/20-radeon.conf will be backed up to home folder</source>
        <translation>          ΣΗΜΕΙΩΣΗ: Θα δημιουργηθεί αντίγραφο ασφαλείας του αρχείου /etc/X11/xorg.conf.d/20-radeon.conf στον αρχικό φάκελο του χρήστη</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1953"/>
        <source>Reset Lightdm (login screen) to system default theme</source>
        <translation>Επαναφορά του προεπιλεγμένου θέματος στο Lightdm (οθόνη σύνδεσης)</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1960"/>
        <source>Root</source>
        <translation>Root</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1970"/>
        <source>Change computer name (requires reboot)</source>
        <extracomment>option to change the system hostname, requires a reboot to be 100% effective</extracomment>
        <translation>Αλλαγή ονόματος του υπολογιστή (απαιτείται επανεκκίνηση)</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1977"/>
        <source>Enable kernel sandbox</source>
        <translation>Ενεργοποίηση sandbox του πυρήνα</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1984"/>
        <source>Enable mounting of internal drives by non-root users</source>
        <translation>Ενεργοποίηση προσάρτησης εσωτερικών δίσκων από μη διαχειριστές</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1991"/>
        <source>Enable Bluetooth battery info for connected devices (requires system restart)</source>
        <extracomment>expose battery info for connected bluetooth devices to the operating system via dbus</extracomment>
        <translation>Ενεργοποίηση πληροφοριών μπαταρίας για τις συνδεδεμένες συσκευές Bluetooth (απαιτείται επανεκκίνηση του συστήματος)</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1998"/>
        <source>Apt installs additional &quot;recommends&quot; packages as dependencies</source>
        <translation>Το apt εγκαθιστά και τα &quot;προτεινόμενα&quot; πακέτα ως εξαρτήσεις</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="2015"/>
        <source>Password for administrative tasks:</source>
        <translation>Κωδικός πρόσβασης για εργασίες διαχειριστή:</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="2022"/>
        <source>put a hold or remove a hold on updates of Liquorix kernels</source>
        <extracomment>toggle for apt hold action on update meta packages</extracomment>
        <translation>αναμονή ή αφαίρεση αναμονής στις ενημερώσεις των πυρήνων Liquorix</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="2025"/>
        <source>Enable Automatic Liquorix Kernel Updates (MX ahs repository)</source>
        <extracomment>uses apt-mark to hold or unhold updates to kernel metapackages</extracomment>
        <translation>Ενεργοποίηση αυτόματων ενημερώσεων του πυρήνα Liquorix (αποθετήριο MX ahs)</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="2032"/>
        <source>          NOTE: existing /etc/X11/xorg.conf.d/20-amd.conf will be backed up to home folder</source>
        <translation>          ΣΗΜΕΙΩΣΗ: Θα δημιουργηθεί αντίγραφο ασφαλείας του αρχείου /etc/X11/xorg.conf.d/20-amd.conf  στον αρχικό φάκελο του χρήστη</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="2056"/>
        <source>Use tearfree radeon driver option</source>
        <translation>Χρήση της επιλογής tearfree στο πρόγραμμα οδήγησης radeon</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="2063"/>
        <source>Use tearfree amdgpu option</source>
        <translation>Χρήση της επιλογής tearfree στο πρόγραμμα οδήγησης amdgpu</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="2070"/>
        <source>Change Default Display Manager (login screen) (requires reboot)</source>
        <extracomment>option to change display manager login screen.  present if more than one display manager is installed</extracomment>
        <translation>Αλλαγή προεπιλεγμένου διαχειριστή οθόνης (οθόνη σύνδεσης) (απαιτεί επανεκκίνηση)</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="2077"/>
        <source>Use Client Side Decorations (CSD) on GTK3 applications that support them (requires session restart)</source>
        <translation>Χρήση Client Side Decorations (CSD) σε εφαρμογές GTK3 που τις υποστηρίζουν (απαιτείται επανεκκίνηση της συνεδρίας)</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="2084"/>
        <source>&amp;User</source>
        <translation>&amp;Χρήστης</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="2091"/>
        <source>put a hold or remove a hold on updates of Debian  kernels</source>
        <extracomment>toggle for apt hold action on update meta packages</extracomment>
        <translation>αναμονή ή αφαίρεση αναμονής στις ενημερώσεις των πυρήνων Debian</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="2094"/>
        <source>Enable Automatic Debian Kernel Updates</source>
        <extracomment>uses apt-mark to hold or unhold updates to kernel metapackages</extracomment>
        <translation>Ενεργοποίηση αυτόματων ενημερώσεων του πυρήνα Debian</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="2114"/>
        <source>          NOTE: existing /etc/X11/xorg.conf.d/20-intel.conf will be backed up to home folder</source>
        <translation>          ΣΗΜΕΙΩΣΗ: Θα δημιουργηθεί αντίγραφο ασφαλείας του αρχείου /etc/X11/xorg.conf.d/20-intel.conf στον αρχικό φάκελο του χρήστη</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="2121"/>
        <source>Generate fluxbox All Apps menu after package installation, removal, and updates</source>
        <translation>Δημιουργία μενού εφαρμογών του fluxbox μετά την εγκατάσταση, την αφαίρεση και τις ενημερώσεις του πακέτου</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="2128"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Early loading of KVM module is new to  kernel 6.12 and conflicts with some non-KVM virtual machine applications, including virtualbox &lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <extracomment>early loading is new on 6.12 kernel and conflicts with virtualbox</extracomment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="2131"/>
        <source>Disable early KVM module load (must be disabled for Virtualbox operation on kernel 6.12 and up)</source>
        <extracomment>disable early loading of KVM module.  necessary for virtualbox to function with kernels 6.12 and up.  actually default behavior on kernels 6.11 and earlier.</extracomment>
        <translation>Απενεργοποίηση της πρόωρης φόρτωσης μονάδων KVM (πρέπει να είναι απενεργοποιημένη για τη λειτουργία του Virtualbox σε πυρήνα 6.12 και άνω)</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="61"/>
        <source>--display switch only valid for Xfce</source>
        <translation>--διακόπτης οθόνης μόνο για το Xfce</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="671"/>
        <source>About MX Tweak</source>
        <translation>Περί του MX Ρυθμίσεις</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="673"/>
        <source>Version: </source>
        <translation>Έκδοση: </translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="674"/>
        <source>App for quick default ui theme changes and tweaks</source>
        <translation>Εφαρμογή για γρήγορες αλλαγές και διορθώσεις του προεπιλεγμένου θέματος</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="676"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Πνευματικά δικαιώματα (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="677"/>
        <source>%1 License</source>
        <translation>Άδεια %1</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="691"/>
        <source>%1 Help</source>
        <translation>Βοήθεια %1</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="701"/>
        <source>Finished! Firefox may require a restart for changes to take effect</source>
        <translation>Ολοκληρώθηκε! Το Firefox μπορεί να χρειαστεί επανεκκίνηση για να ισχύσουν οι αλλαγές</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="748"/>
        <source>Plese remove special characters</source>
        <translation>Παρακαλώ αφαιρέστε τους ειδικούς χαρακτήρες</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="748"/>
        <source>from file name</source>
        <translation>από το όνομα του αρχείου</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="755"/>
        <source>File name already exists.  Choose another name</source>
        <translation>Υπάρχει το όνομα του αρχείου.  Επιλέξτε άλλο όνομα</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="783"/>
        <source>File is not a valid tar.xz archive file</source>
        <translation>Το αρχείο δεν είναι έγκυρο αρχείο αρχειοθέτησης tar.xz</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="786"/>
        <source>Archive does not contain a panel config</source>
        <translation>Το αρχείο δεν περιέχει ρυθμίσεις του ταμπλό</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="961"/>
        <source>Panel settings</source>
        <translation>Ρυθμίσεις ταμπλό</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="962"/>
        <source>Your current panel settings have been backed up in a hidden folder called .restore in your home folder (~/.restore/)</source>
        <translation>Οι τρέχουσες ρυθμίσεις του ταμπλό σας αποθηκεύτηκαν σαν αντίγραφο ασφαλείας, σε έναν κρυφό φάκελο με όνομα .restore στον αρχικό κατάλογο του χρήστη (~/.restore /)</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="1662"/>
        <source>Plasma Widget Themes</source>
        <comment>theme style of the kde plasma widgets</comment>
        <translation>Θέματα Widget Plasma</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="1663"/>
        <source>Color Schemes</source>
        <comment>plasma widget color schemes</comment>
        <translation>Χρωματικά σχήματα</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="1664"/>
        <source>Plasma Look &amp; Feel Global Themes</source>
        <comment>plasma global themes</comment>
        <translation>Plasma Look &amp; Feel Παγκόσμια θέματα</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="1932"/>
        <source>settings</source>
        <translation>ρυθμίσεις</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="2273"/>
        <source>Choose a theme set</source>
        <translation>Επιλογή θέματος</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="2737"/>
        <source>Please enter a computer name.</source>
        <comment>question to enter a name for the computer hostname</comment>
        <translation>Εισαγάγετε ένα όνομα υπολογιστή.</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="2741"/>
        <source>Sorry, your computer name contains invalid characters.
You&apos;ll have to select a different
name before proceeding.</source>
        <comment>unacceptable characters are found in hostname, pick a new name</comment>
        <translation>Λυπούμαστε, το όνομα του υπολογιστή σας περιέχει μη έγκυρους χαρακτήρες.
Θα πρέπει να επιλέξετε διαφορετικό
πριν προχωρήσετε.</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="4374"/>
        <source>Select application to run</source>
        <comment>will show in file dialog when selection an application to run</comment>
        <translation>Επιλογή εφαρμογής για εκτέλεση</translation>
    </message>
</context>
<context>
    <name>remove_user_theme_set</name>
    <message>
        <location filename="../remove_user_theme_set.ui" line="14"/>
        <source>Remove User Theme Set</source>
        <translation>Αφαίρεση θέματος</translation>
    </message>
</context>
<context>
    <name>theming_to_tweak</name>
    <message>
        <location filename="../theming_to_tweak.ui" line="14"/>
        <source>New Theme Set</source>
        <translation>Νέο θέμα</translation>
    </message>
    <message>
        <location filename="../theming_to_tweak.ui" line="20"/>
        <source>Enter name for new theme set</source>
        <translation>Εισαγάγετε όνομα για το νέο θέμα</translation>
    </message>
</context>
<context>
    <name>window_buttons</name>
    <message>
        <location filename="../window_buttons.ui" line="14"/>
        <location filename="../window_buttons.cpp" line="24"/>
        <source>Window Buttons</source>
        <translation>Κουμπιά παραθύρων</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="28"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Appearance&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Εμφάνιση&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="35"/>
        <source>Show button labels</source>
        <translation>Εμφάνιση ετικετών στα κουμπιά</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="42"/>
        <source>Show flat buttons</source>
        <translation>Χρήση επίπεδων κουμπιών</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="49"/>
        <source>Show handle</source>
        <translation>Εμφάνιση χειρολαβής</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="56"/>
        <source>Sorting Order:</source>
        <translation>Σειρά ταξινόμησης:</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="64"/>
        <source>Timestamp</source>
        <translation>Χρονοσήμανση</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="69"/>
        <source>Group title and timestamp</source>
        <translation>Ομαδοποίηση τίτλου και χρόνου</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="74"/>
        <source>Window Title</source>
        <translation>Τίτλος παραθύρου</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="79"/>
        <source>Group title and window title</source>
        <translation>Ομαδοποίηση τίτλου και τίτλου παραθύρου</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="84"/>
        <source>None, allow drag-and-drop</source>
        <translation>Κανένα, να επιτρέπεται η μεταφορά και απόθεση (drag-and-drop)</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="92"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Behavior&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Συμπεριφορά&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="99"/>
        <source>Window grouping:</source>
        <translation>Ομαδοποίηση παραθύρων:</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="107"/>
        <source>Never</source>
        <translation>Ποτέ</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="112"/>
        <source>Always</source>
        <translation>Πάντα</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="120"/>
        <source>Middle click action:</source>
        <translation>Ενέργεια μεσαίου κλικ:</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="128"/>
        <source>Nothing</source>
        <translation>Τίποτα</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="133"/>
        <source>Close window</source>
        <translation>Κλείσιμο παραθύρου</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="138"/>
        <source>Minimize window</source>
        <translation>Ελαχιστοποίηση παραθύρου</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="146"/>
        <source>Restore minimized windows to current workspace</source>
        <translation>Επαναφορά ελαχιστοποίησης των παραθύρων στο τωρινό χώρο εργασίας</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="153"/>
        <source>Draw window frame when hovering over a button</source>
        <translation>Σχεδίαση του περιγράμματος παραθύρου όταν ο δείκτης περνάει πάνω από ένα κουμπί</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="160"/>
        <source>Switch windows using the mouse wheel</source>
        <translation>Εναλλαγή παραθύρων με το τροχό του ποντικιού</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="167"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Filtering&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Φιλτράρισμα&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="174"/>
        <source>Show windows from all workspaces or viewports</source>
        <translation>Εμφάνιση παραθύρων από όλους τους χώρους εργασίας ή τα παράθυρα προβολής</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="181"/>
        <source>Show only minimized windows</source>
        <translation>Εμφάνιση μόνο ελαχιστοποιημένων παραθύρων</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="188"/>
        <source>Show windows from all monitors</source>
        <translation>Προβολή παραθύρων από όλες τις οθόνες</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="238"/>
        <source>Close</source>
        <translation>Κλείσιμο</translation>
    </message>
</context>
<context>
    <name>xfwm_compositor_settings</name>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="14"/>
        <source>Dialog</source>
        <translation>Παράθυρο</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="42"/>
        <source>Popup Windows</source>
        <translation>Διαφάνεια αναδυόμενων παραθύρων</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="49"/>
        <source>Windows during move</source>
        <translation>Διαφάνεια παραθύρων κατά τη μετακίνηση</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="56"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Opacity Settings&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Ρυθμίσεις διαφάνειας&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="79"/>
        <source>Window decorations</source>
        <translation>Διαφάνεια περιγραμμάτων παραθύρων</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="86"/>
        <source>Show shadows under dock windows</source>
        <translation>Εμφάνιση σκιών κάτω από τα παράθυρα dock</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="93"/>
        <source>Show shadows under popup windows</source>
        <translation>Εμφάνιση σκιών στα αναδυόμενα παράθυρα</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="100"/>
        <source>Windows during resize</source>
        <translation>Διαφάνεια παραθύρων κατά την αλλαγή μεγέθους</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="123"/>
        <source>Show shadows under regular windows</source>
        <translation>Εμφάνιση σκιών στα κανονικά παράθυρα</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="130"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Feature Settings&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Ρυθμίσεις δυνατοτήτων&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="137"/>
        <source>Show windows preview in place of icons when cycling</source>
        <translation>Εμφάνιση επισκόπησης των παραθύρων στη θέση των εικονιδίων κατά τη κυκλική εναλλαγή</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="144"/>
        <source>Display fullscreen overlay windows directly</source>
        <translation>Άμεση απεικόνιση των επικαλυπτόμενων παραθύρων πλήρους οθόνης</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="183"/>
        <source>Inactive windows</source>
        <translation>Διαφάνεια ανενεργών παραθύρων</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="190"/>
        <source>Synchronize drawing to vertical blank</source>
        <translation>Συγχρονισμός σχεδίασης σε vblank</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="212"/>
        <source>Close</source>
        <translation>Κλείσιμο</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.cpp" line="23"/>
        <source>Xfwm Compositor Settings</source>
        <translation>Ρυθμίσεις συνθέτη Xfwm</translation>
    </message>
</context>
</TS>
